@@ -1,24 +1,29 @@
-import pandas as pd
-import numpy as np
+from math import ceil
+from operator import itemgetter
 
-from sklearn.feature_extraction.text import TfidfVectorizer, CountVectorizer
+import numpy as np
+import pandas as pd
+from gensim.corpora import Dictionary
+from gensim.models import CoherenceModel, nmf
 from sklearn.decomposition import NMF
-from sklearn.feature_extraction.text import ENGLISH_STOP_WORDS
-from datto.CleanText import CleanText
+from sklearn.feature_extraction.text import (
+    ENGLISH_STOP_WORDS,
+    CountVectorizer,
+    TfidfVectorizer,
+)
 from sklearn.linear_model import ElasticNet, LogisticRegression
-from sklearn.model_selection import train_test_split
 from sklearn.metrics import (
     accuracy_score,
     mean_squared_error,
+    median_absolute_error,
     precision_score,
+    r2_score,
     recall_score,
     roc_auc_score,
-    median_absolute_error,
-    r2_score,
 )
-from gensim.corpora import Dictionary
-from gensim.models import nmf, CoherenceModel
-from operator import itemgetter
+from sklearn.model_selection import train_test_split
+
+from datto.CleanText import CleanText
 
 
 class ModelResults:
@@ -65,10 +70,16 @@ class ModelResults:
         # Create the bag-of-words format (list of (token_id, token_count))
         corpus = [dictionary.doc2bow(text) for text in texts]
 
-        if X.shape[0] < 55:
-            topic_nums = list(np.arange(5, X.shape[0], 5))
-        else:
-            topic_nums = list(np.arange(5, 55, 5))
+        if X.shape[0] < 20:
+            return "Too few examples to categorize."
+
+        # In case 1, add 1 to get at least 2
+        # The rest are based on eyeballing numbers
+        min_topics = ceil(X.shape[0] * 0.01) + 1
+        max_topics = ceil(X.shape[0] * 0.4)
+        step = ceil((max_topics - min_topics) / 5)
+
+        topic_nums = list(np.arange(min_topics, max_topics, step))
 
         coherence_scores = []
 
